@@ -30,7 +30,7 @@ Class::Inspector - Get information about a class and its structure
 =head1 DESCRIPTION
 
 Class::Inspector allows you to get information about a loaded class. Most or
-all of this information can be found in other ways, but they arn't always
+all of this information can be found in other ways, but they aren't always
 very friendly, and usually involve a relatively high level of Perl wizardry,
 or strange and unusual looking code. Class::Inspector attempts to provide 
 an easier, more friendly interface to this information.
@@ -39,24 +39,25 @@ an easier, more friendly interface to this information.
 
 =cut
 
-use 5.005;
+use 5.006;
 # We don't want to use strict refs anywhere in this module, since we do a
-# lot of things in here that arn't strict refs friendly.
+# lot of things in here that aren't strict refs friendly.
 use strict qw{vars subs};
+use warnings;
 use File::Spec ();
 
 # Globals
 use vars qw{$VERSION $RE_IDENTIFIER $RE_CLASS $UNIX};
 BEGIN {
-	$VERSION = '1.21_01';
+	$VERSION = '1.26_01';
 
 	# If Unicode is available, enable it so that the
 	# pattern matches below match unicode method names.
 	# We can safely ignore any failure here.
-	eval {
-		require utf8;
-		utf8->import;
-	};
+	SCOPE: {
+		local $@;
+		eval "require utf8; utf8->import";
+	}
 
 	# Predefine some regexs
 	$RE_IDENTIFIER = qr/\A[^\W\d]\w*\z/s;
@@ -117,12 +118,13 @@ sub loaded {
 }
 
 sub _loaded {
-	my ($class, $name) = @_;
+	my $class = shift;
+	my $name  = shift;
 
 	# Handle by far the two most common cases
 	# This is very fast and handles 99% of cases.
 	return 1 if defined ${"${name}::VERSION"};
-	return 1 if defined @{"${name}::ISA"};
+	return 1 if @{"${name}::ISA"};
 
 	# Are there any symbol table entries other than other namespaces
 	foreach ( keys %{"${name}::"} ) {
@@ -489,6 +491,7 @@ sub subclasses {
 			# over that (bizarre) class. That would at limit
 			# problems with finding subclasses to only the
 			# modules that have broken ->isa implementation.
+			local $@;
 			eval {
 				if ( $c->isa($name) ) {
 					# Add to the found list, but don't add the class itself
@@ -606,10 +609,6 @@ sub _inc_to_local {
 
 =pod
 
-=head1 TO DO
-
-- Adding Class::Inspector::Functions
-
 =head1 SUPPORT
 
 Bugs should be reported via the CPAN bug tracker
@@ -628,7 +627,7 @@ L<http://ali.as/>, L<Class::Handle>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2002 - 2006 Adam Kennedy.
+Copyright 2002 - 2012 Adam Kennedy.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
